@@ -1,4 +1,4 @@
-"""Flax extras."""
+r"""Flax extras."""
 
 from flax_extra import (
     util,
@@ -6,6 +6,7 @@ from flax_extra import (
     console,
     batch,
     operator,
+    data,
     layer,
     model,
     training,
@@ -19,6 +20,7 @@ __all__ = [
     "console",
     "batch",
     "operator",
+    "data",
     "layer",
     "model",
     "training",
