@@ -1,4 +1,4 @@
-"""Evaluation API."""
+r"""Evaluation API."""
 
 from flax_extra.evaluation._loop import EvalLoop, EvalTask
 
