@@ -1,15 +1,15 @@
-"""The shift-right operator."""
+r"""The shift-right operator."""
 
-from typing import Any
+from typing import List
 from dataclasses import dataclass
 from jax import numpy as jnp
 
-Array = Any
+Array = jnp.ndarray
 
 
 @dataclass
 class ShiftRight:
-    """Inserts padding to shift the sequence.
+    r"""Inserts padding to shift the sequence.
 
     >>> from jax import numpy as jnp
     >>> from flax_extra import operator as op
@@ -19,16 +19,16 @@ class ShiftRight:
     """
 
     n_positions: int = 1
-    """a number of positions to shift."""
+    r"""a number of positions to shift."""
 
     pad_id: int = 0
-    """a padding identifier to insert."""
+    r"""a padding identifier to insert."""
 
     axis: int = 0
-    """the operation will be performed along this axis."""
+    r"""the operation will be performed along this axis."""
 
     def __call__(self, inputs: Array) -> Array:
-        def pad_width() -> Array:
+        def pad_width() -> List[tuple[int, int]]:
             acc = [(0, 0)] * len(inputs.shape)
             acc[self.axis] = (self.n_positions, 0)
             return acc
@@ -39,7 +39,7 @@ class ShiftRight:
             mode="constant",
             constant_values=self.pad_id,
         )
-        return jnp.take(
+        return jnp.take(  # type: ignore
             padded,
             jnp.arange(padded.shape[self.axis] - self.n_positions),
             axis=self.axis,
