@@ -1,4 +1,4 @@
-"""Training API."""
+r"""Training API."""
 
 from flax_extra.training._loop import TrainLoop, TrainTask
 
